@@ -23,30 +23,35 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: cfgvar.c,v 1.29 2004/03/19 08:12:30 vlm Exp $
+ * $Id: cfgvar.c,v 1.36 2004/11/15 16:57:01 vlm Exp $
  */
 
 #include "ipcad.h"
 #include "sf_lite.h"
 #include "cfgvar.h"
 #include "disp.h"
+#include "opt.h"
 
 
-config_t static_config;
-config_t *conf = &static_config;
-
 /*
  * Run-time global variables
  */
+int agr_portmap[65536];	/* Ports aggregation table */
+config_t static_config;
+config_t *conf = &static_config;
 
-int
+/*
+ * Configure and initialize the specified packet source (interface).
+ */
+packet_source_t *
 cfg_add_iface(char *iface, int iflags, char *filter) {
 	packet_source_t *ps;
 	int ret;
 
 	fprintf(stderr, "Opening %s... ", iface);
 
-	if(conf->capture_ports)
+	if(!(iflags & IFLAGS_STRICT) && conf->capture_ports)
+		/* Inherit current capture_ports setting */
 		iflags |= IFLAG_RSH_EXTRA | IFLAG_LARGE_CAP;
 	if(!(iflags & IFLAG_NF_DISABLE))
 		iflags |= IFLAG_LARGE_CAP;
@@ -60,14 +65,14 @@ cfg_add_iface(char *iface, int iflags, char *filter) {
 	 */
 	ps = create_packet_source(iface, iflags, filter);
 	if(ps == NULL) {
-		perror("Can't initialize");
-		exit(EX_NOINPUT);
+		perror("Can't construct");
+		return NULL;
 	}
 
 	/*
 	 * Initialize the packet source.
 	 */
-	ret = init_packet_source(ps);
+	ret = init_packet_source(ps, 0);
 	if(ret == -1) {
 		switch(errno) {
 		case ENETDOWN:
@@ -85,7 +90,8 @@ cfg_add_iface(char *iface, int iflags, char *filter) {
 			break;
 		default:
 			perror("Can't initialize");
-			exit(EX_NOINPUT);
+			destroy_packet_source(ps);
+			return NULL;
 		}
 		assert(ps->state == PST_EMBRYONIC);
 	}
@@ -93,15 +99,16 @@ cfg_add_iface(char *iface, int iflags, char *filter) {
 	/*
 	 * Add the packet source into the list.
 	 */
+	pthread_mutex_lock(&packet_sources_list_lock);
 	ps->next = conf->packet_sources_head;
 	conf->packet_sources_head = ps;
+	pthread_mutex_unlock(&packet_sources_list_lock);
 
 	fprintf(stderr, "Initialized as %d\n", ps->ifIndex);
 
-	return 0;
+	return ps;
 }
 
-
 struct rsh_entries {
 	char *username;
 	unsigned int addr;
@@ -116,14 +123,9 @@ cfg_add_rsh_host(char *ru, char *rh, int privlevel) {
 	unsigned int ia;
 	struct rsh_entries *res;
 	
-	if(!ru || !rh) {
-		fprintf(stderr, "Invalid [user@]host_addr specification: %s\n", rh);
-		exit(EX_DATAERR);
-	}
-
-	if( sf_iaton(rh, &ia) == -1 ) {
-		perror("host_addr:");
-		fprintf(stderr, "Invalid [user@]host_addr specification: %s", rh);
+	if(!ru || !rh || sf_iaton(rh, &ia) == -1) {
+		fprintf(stderr,
+			"Invalid [user@]<host-ip> specification: %s\n", rh);
 		exit(EX_DATAERR);
 	}
 
@@ -175,34 +177,26 @@ cfg_check_rsh(char *ru, struct in_addr *ia) {
 
 int
 cfg_add_aggregate_ports_table(int from, int to, int into) {
-	struct ap_table *apt;
+	int i;
 
-	if((apt = conf->ap_table) == NULL) {
-		apt = conf->ap_table = malloc(sizeof *apt);
-	} else {
-		while(apt->next)
-			apt = apt->next;
-		apt = apt->next = malloc(sizeof *apt);
+	if(from < 0 || from > 65535
+	|| to < 0 || to > 65535) {
+		fprintf(stderr, "%d..%d->%d: Values out of range 0..65535\n",
+			from, to, into);
+		errno = ERANGE;
+		return -1;
 	}
 
-	if(apt == NULL) {
-		fprintf(stderr, "Memory allocation failed.\n");
-		exit(EX_OSERR);
-	}
-
-
 	if(to < from) {
 		int tmp = from;
 		from = to;
 		to = tmp;
 	}
 
-	apt->port_start = from;
-	apt->port_end = to;
-	apt->port_into = into;
-	apt->next = NULL;
+	for(i = from; i <= to; i++)
+		agr_portmap[i] = into;
 
-	printf("Aggregate ports %d-%d into %d\n",
+	printf("Aggregate ports %d..%d into %d\n",
 		from, to, into);
 
 	return 0;
@@ -234,7 +228,7 @@ cfg_add_atable2(unsigned int ip, unsigned int mask, unsigned int strip) {
 	if(strip == (unsigned int)-1) {
 		at->strip_bits = 32;
 	} else {
-		u_int32_t __n = strip;
+		unsigned __n = strip;
 		__n = (__n & 0x55555555) + ((__n & 0xaaaaaaaa) >> 1);
 		__n = (__n & 0x33333333) + ((__n & 0xcccccccc) >> 2);
 		__n = (__n & 0x0f0f0f0f) + ((__n & 0xf0f0f0f0) >> 4);
@@ -288,21 +282,70 @@ cfg_add_atable(char *sip, char *smask, char *sstrip) {
 }
 
 
-int
-init_packet_source(packet_source_t *ps) {
+static genhash_t *ifclass2id;
+struct ifclass_id_s {
+	int id_from;
+	int id_to;
+};
 
-	if(strncasecmp(ps->ifName, "ulog", 5) == 0) {
-		return init_packet_source_ulog(ps, 1);
+int
+cfg_add_ifclass_map(char *ifclass, int range_start, int range_stop) {
+	struct ifclass_id_s *id;
+
+	if(!ifclass || range_start < 0 || range_start > range_stop) {
+		errno = EINVAL;
+		return -1;
 	}
 
-#ifdef	PSRC_bpf
-	return init_packet_source_bpf(ps);
-#elif	PSRC_pcap
-	return init_packet_source_pcap(ps);
-#else
-#error	unknown packet source
-#endif
+	if(!ifclass2id) {
+		ifclass2id = genhash_new(cmpf_string, hashf_string, free, free);
+		if(!ifclass2id) return -1;
+	}
 
+	id = calloc(1, sizeof *id);
+	if(!id) return -1;
+
+	id->id_from = range_start;
+	id->id_to = range_stop;
+
+	if(genhash_add(ifclass2id, ifclass, id)) {
+		free(id);
+		return -1;
+	}
+
+	return 0;
 }
 
+/*
+ * Convert interface name ("ppp32") into SNMP index (32) for NetFlow.
+ */
+int
+iface_to_snmp_id(const char *ifname) {
+	char name[IFNAMSIZ];
+	char *n = name;
+	char *nend = name + sizeof(name);
+	struct ifclass_id_s *id;
+	int ifnum;
 
+	if(!ifclass2id) return -1;
+
+	for(; n < nend; ifname++, n++) {
+		if(*ifname >= '0' && *ifname <= '9') {
+			*n = 0;
+			break;
+		} else {
+			if(!(*n = *ifname))
+				break;
+		}
+	}
+	if(n == nend) return -1;
+
+	id = genhash_get(ifclass2id, name);
+	if(!id) return -1;
+
+	ifnum = id->id_from + atoi(ifname);
+	if(ifnum > id->id_to)
+		ifnum = id->id_to;
+
+	return ifnum;
+}
