@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2001 Lev Walkin <vlm@lionet.info>.
+ * Copyright (c) 2001, 2005 Lev Walkin <vlm@lionet.info>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: cfgvar.h,v 1.14 2004/03/19 08:12:30 vlm Exp $
+ * $Id: cfgvar.h,v 1.17 2005/03/22 17:55:14 vlm Exp $
  */
 #ifndef	__CFGVAR_H__
 #define	__CFGVAR_H__
@@ -31,7 +31,9 @@
 #include "ipcad.h"
 
 /*
- * IP networks aggregation table.
+ * IP networks aggregation list.
+ * This list implies linear scan, but should be fine for
+ * small number of aggregated networks.
  */
 struct atable {
 	struct in_addr ip;
@@ -44,15 +46,9 @@ struct atable {
 /*
  * Ports aggregation table.
  */
-struct ap_table {
-	int port_start;
-	int port_end;
-	int port_into;
-	struct ap_table *next;
-};
+extern int agr_portmap[65536];
 
 typedef struct config_s {
-
 	uid_t set_uid;
 	gid_t set_gid;
 
@@ -69,7 +65,6 @@ typedef struct config_s {
 	packet_source_t *packet_sources_head;
 
 	struct atable *atable;
-	struct ap_table *ap_table;
 
 	int capture_ports;	/* Whether to display UDP/TCP ports */
 
@@ -78,8 +73,12 @@ typedef struct config_s {
 	int netflow_timeout_active;	/* Flow timeout, in seconds */
 	int netflow_timeout_inactive;	/* Flow timeout, in seconds */
 	int netflow_packet_interval;	/* Sampling mode, in packets */
+	int netflow_engine_type;	/* v5 engine-type */
+	int netflow_engine_id;		/* v5 engine-id */
 } config_t;
 
+extern pthread_mutex_t packet_sources_list_lock;
+
 
 /* Globally visible configuration */
 extern config_t *conf;
@@ -94,13 +93,16 @@ extern size_t used_memory;
  * Constructors used by the configuration reader.
  */
 
-int cfg_add_iface(char *, int iflags, char *filter);
+packet_source_t *cfg_add_iface(char *, int iflags, char *filter);
 int cfg_add_rsh_host(char *ru, char *rh, int privlevel);
 int cfg_check_rsh(char *ru, struct in_addr *);
 
 int cfg_add_atable(char *ip, char *mask, char *strip);
 int cfg_add_aggregate_ports_table(int from, int to, int into);
 
+int cfg_add_ifclass_map(char *ifclass, int range_start, int range_stop);
+int iface_to_snmp_id(const char *interface_name);
+
 
 /*
  * Misc methods.
