@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: disp.c,v 1.27 2004/03/11 09:36:00 vlm Exp $
+ * $Id: disp.c,v 1.32 2004/11/12 06:38:03 vlm Exp $
  */
 
 #include "ipcad.h"
@@ -103,14 +103,14 @@ display(FILE *f, disp_storage_e dstore) {
 
 	if(dstore == DS_NETFLOW) {
 		putc('\n', f);
-		fprintf(f, "IP Flow Switching Cache, %d bytes\n",
-			entries * sizeof(*active_storage.buckets[0]));
-		fprintf(f, "  %d flows, %lld flow alloc failures\n",
-			entries, ex_packets);
-		fprintf(f, "  Active flows timeout in %d minutes\n",
-			conf->netflow_timeout_active / 60);
-		fprintf(f, "  Inactive flows timeout in %d seconds\n",
-			conf->netflow_timeout_inactive);
+		fprintf(f, "IP Flow Switching Cache, %ld bytes\n",
+			(long)entries * sizeof(*active_storage.buckets[0]));
+		fprintf(f, "  %ld flows, %lld flow alloc failures\n",
+			(long)entries, ex_packets);
+		fprintf(f, "  Active flows timeout in %ld minutes\n",
+			(long)(conf->netflow_timeout_active / 60));
+		fprintf(f, "  Inactive flows timeout in %ld seconds\n",
+			(long)conf->netflow_timeout_inactive);
 	}
 
 	/*
@@ -162,12 +162,19 @@ dump_flow_table(FILE *f, flow_t *flow, int entries, disp_storage_e mode) {
 			int sport = flow->src_port;
 			int dport = flow->dst_port;
 			if(sport == -1) sport = dport = 0;
-			fprintf(f, "%-13s", IFNameByIndex(flow->ifIndex));
+			if(flow->ifInName[0])
+				fprintf(f, "%-13s", flow->ifInName);
+			else
+				fprintf(f, "%-13s",
+					IFNameBySource(flow->ifSource));
 			print_aligned_ip(f, flow->src);
-			fprintf(f, "%-13s", "<?>");
+			if(flow->ifOutName[0])
+				fprintf(f, "%-13s", flow->ifOutName);
+			else
+				fprintf(f, "%-13s", "<?>");
 			print_aligned_ip(f, flow->dst);
-			fprintf(f, "%02x %04x %04x %5d",
-				flow->ip_p, sport, dport, flow->packets);
+			fprintf(f, "%02x %04x %04x %5ld",
+				flow->ip_p, sport, dport, (long)flow->packets);
 			putc('\n', f);
 		}
 		putc('\n', f);
@@ -191,18 +198,20 @@ dump_flow_table(FILE *f, flow_t *flow, int entries, disp_storage_e mode) {
 		print_aligned_ip(f, flow->dst);
 		fprintf(f,
 			conf->capture_ports
-			?"%8u %12qu"
-			:"%18u %19qu",
-			flow->packets, flow->bytes);
+			?"%8lu %12qu"
+			:"%18lu %19qu",
+			(unsigned long)flow->packets, flow->bytes);
 		if(conf->capture_ports) {
 			if(flow->src_port == -1)
 				fprintf(f, " %6s %5s", "-", "-");
 			else
 				fprintf(f, " %6d %5d",
 					flow->src_port, flow->dst_port);
-			fprintf(f, " %5d %4s",
-				flow->ip_p,
-				IFNameByIndex(flow->ifIndex));
+			fprintf(f, " %5d ", flow->ip_p);
+			if(flow->ifInName[0])
+				fprintf(f, "%4s", flow->ifInName);
+			else
+				fprintf(f, "%4s", IFNameBySource(flow->ifSource));
 		}
 		putc('\n', f);
 	}
@@ -226,18 +235,19 @@ show_stats(FILE *f) {
 		ps->print_stats(f, ps);
 	}
 
-	fprintf(f, "Flow entries made: %d\n", active_entries);
+	fprintf(f, "Flow entries made: %ld\n", (long)active_entries);
 	if(conf->netflow_enabled)
-	fprintf(f, "NetFlow cached flows: %d\n", netflow_entries);
+	fprintf(f, "NetFlow cached flows: %ld\n", (long)netflow_entries);
 
 	if(conf->memsize)   
-		fprintf(f, "Memory usage: %d%% (%u from %u)\n",
-			used_memory * 100 / conf->memsize,
-			used_memory, conf->memsize);
+		fprintf(f, "Memory usage: %ld%% (%ld from %ld)\n",
+			(long)(used_memory * 100 / conf->memsize),
+			(long)used_memory, (long)conf->memsize);
 	else
-		fprintf(f, "Memory usage: %u kbytes.\n", used_memory >> 10);
+		fprintf(f, "Memory usage: %ld kbytes.\n",
+			(long)(used_memory >> 10));
 
-	fprintf(f, "Free slots for rsh clients: %d\n", max_clients);
+	fprintf(f, "Free slots for rsh clients: %ld\n", (long)max_clients);
 
 	ipcad_uptime(f);
 	system_uptime(f);
@@ -268,7 +278,7 @@ display_internal_averages(FILE *f, const char *ifname) {
 void
 show_version(FILE *f) {
 	fprintf(f,
-		IPCAD_VERSION_STRING "\n"
+		IPCAD_VERSION_STRING
 		IPCAD_COPYRIGHT "\n"
 		"\n"
 	);
