@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: dump.c,v 1.12 2004/03/06 05:29:15 vlm Exp $
+ * $Id: dump.c,v 1.14 2006/11/21 14:56:36 vlm Exp $
  */
 
 #include "ipcad.h"
@@ -84,10 +84,20 @@ make_dump(char *dump_file, FILE *msgstream) {
 		return -1;
 	}
 
-	if(sb.st_uid != getuid()) {
-		fprintf(msgstream, "Invalid dump file owner.\n");
-		close(df);
-		return -1;
+	if(1) {
+		uid_t should_be = conf->set_uid;
+		if((int)should_be <= 0)
+			should_be = getuid();
+		if(sb.st_uid != should_be) {
+			fprintf(msgstream,
+				"Invalid dump file owner: "
+				"%ld should be %ld\n",
+				(long)sb.st_uid,
+				(long)should_be
+			);
+			close(df);
+			return -1;
+		}
 	}
 
 	if((sb.st_mode & 0077)) {
