@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: headers.h,v 1.22 2004/03/19 08:59:42 vlm Exp $
+ * $Id: headers.h,v 1.35 2005/09/06 02:43:23 vlm Exp $
  */
 #ifndef	__HEADERS_H__
 #define	__HEADERS_H__
@@ -76,6 +76,14 @@
 #include <net/if.h>
 #endif
 
+#ifdef HAVE_NET_ROUTE_H
+#include <net/route.h>
+#endif
+
+#ifdef HAVE_IFADDRS_H
+#include <ifaddrs.h>
+#endif
+
 #ifdef HAVE_NET_ETHERNET_H
 #include <net/ethernet.h>
 #endif
@@ -134,6 +142,10 @@
 #include <paths.h>
 #endif
 
+#include <poll.h>
+#include <signal.h>
+#include <fnmatch.h>
+
 #include <assert.h>
 
 #ifndef	IPPROTO_SCTP
@@ -150,16 +162,40 @@
 #define ETHER_HDR_LEN	(ETHER_ADDR_LEN*2+ETHER_TYPE_LEN)
 #endif	/* ETHER_HDR_LEN */
 
-
-#ifdef	HAVE_LINUX_NETFILTER_IPV4_IPT_ULOG_H
+#ifdef	HAVE_ASM_TYPES_H
 #include <asm/types.h>
+#endif
+
+#ifdef	HAVE_LINUX_SOCKET_H
+#include <linux/socket.h>
+#endif
+
+#ifdef	HAVE_LINUX_NETLINK_H
 #include <linux/netlink.h>
+#endif
+
+#ifdef	HAVE_LINUX_NETFILTER_H
+#include <linux/netfilter.h>
+#endif
+
+/*
+ * Linux ULOG support
+ */
+#ifdef	HAVE_LINUX_NETFILTER_IPV4_IPT_ULOG_H
 #include <linux/netfilter_ipv4/ipt_ULOG.h>
-#endif	/* Linux ULOG support */
+#define	PSRC_ulog
+#endif
 
-#undef	HAVE_NET_BPF_H
+/*
+ * Linux IPQ/libipq(3) support
+ */
+#ifdef	HAVE_LINUX_NETFILTER_IPV4_IP_QUEUE_H
+#include <linux/netfilter_ipv4/ip_queue.h>
+#define	PSRC_ipq
+#endif
 
-#if defined(HAVE_NET_BPF_H) && ( defined(__FreeBSD__) || defined(__OpenBSD__) )
+
+#if defined(HAVE_NET_BPF_H) 
 #include <net/bpf.h>
 #endif	/* #ifdef HAVE_NET_BPF_H */
 
@@ -169,7 +205,7 @@
 #ifdef	HAVE_PCAP_PCAP_H
 #include <pcap/pcap.h>
 #else	/* #ifdef HAVE_PCAP_PCAP_H */
-#if defined(HAVE_NET_BPF_H) && ( defined(__FreeBSD__) || defined(__OpenBSD__) )
+#if defined(HAVE_NET_BPF_H)
 /* Whooh */
 #else
 #error	No BPF or PCAP installed. Aborting.
@@ -177,13 +213,22 @@
 #endif	/* #ifdef HAVE_PCAP_PCAP_H */
 #endif	/* #ifdef HAVE_PCAP_H */
 
-#include <poll.h>
-#include <signal.h>
+#if	defined(HAVE_NET_ROUTE_H) && !defined(__linux__)
+#define	IPCAD_DYNAMIC_ROUTING_SOCKET
+#endif
+
+#if	defined(HAVE_IFADDRS_H) && defined(HAVE_GETIFADDRS)
+#define	IPCAD_IFLIST_USE_GETIFADDRS
+#endif
 
 #ifndef HAVE_SOCKLEN_T
 typedef size_t	socklen_t;
 #endif
 
+#ifndef HAVE_IN_ADDR_T
+typedef unsigned int in_addr_t;
+#endif
+
 #ifndef	HAVE_STRTOULL
 #ifdef	HAVE_STRTOUQ
 #define	strtoull(a,b,c)	strtouq(a,b,c)
@@ -206,9 +251,8 @@ typedef size_t	socklen_t;
 #define	offsetof(T, m)	(((void *)&(((T *)0)->m)) - (void *)0)
 #endif	/* offsetof */
 
-#ifndef	HAVE_PTHREAD_CANCEL
-#define	pthread_cancel(foo)		((void)0)
-#define	pthread_setcancelstate(foo,bar)	((void)0)
-#endif	/* HAVE_PTHREAD_CANCEL */
+#ifndef	MIN
+#define	MIN(a,b)	((a)<(b)?(a):(b))
+#endif	/* MIN */
 
 #endif	/* __HEADERS_H__ */
