@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2001 Lev Walkin <vlm@lionet.info>.
+ * Copyright (c) 2001, 2004 Lev Walkin <vlm@lionet.info>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ifst_bsd.c,v 1.6 2004/03/09 22:08:19 vlm Exp $
+ * $Id: ifst_bsd.c,v 1.11 2004/05/10 08:25:30 vlm Exp $
  */
 
 /*
@@ -59,16 +59,17 @@
  * SUCH DAMAGE.
  */
 
-#include "ipcad.h"
-#include "disp.h"
-
+#include <sys/types.h>
 #include <sys/param.h>
 #include <sys/ioctl.h>
 #include <sys/socket.h>
 #include <sys/sysctl.h>
 #include <sys/time.h>
 
-#ifndef __OpenBSD__
+#include "ipcad.h"
+#include "disp.h"
+
+#ifdef __FreeBSD__
 #include <sys/module.h>
 #include <sys/linker.h>
  
@@ -95,9 +96,9 @@
 #include <string.h>
 #include <unistd.h>
 
-void	rt_xaddrs __P((caddr_t, caddr_t, struct rt_addrinfo *));
-void	status __P((FILE *f, const char *ifname,
-		    struct sockaddr_dl *sdl, struct if_msghdr *ifm));
+void	rt_xaddrs (caddr_t, caddr_t, struct rt_addrinfo *);
+void	status (FILE *f, const char *ifname,
+		    struct sockaddr_dl *sdl, struct if_msghdr *ifm);
 
 void in_status(FILE *, struct rt_addrinfo *, int flags);
 void ether_status(FILE *, struct rt_addrinfo *);
@@ -171,7 +172,7 @@ if_stat(FILE *f, char *ifname) {
 	mib[0] = CTL_NET;
 	mib[1] = PF_ROUTE;
 	mib[2] = 0;
-	mib[3] = 0;	/* address family */
+	mib[3] = AF_INET;	/* address family */
 	mib[4] = NET_RT_IFLIST;
 	mib[5] = 0;
 
@@ -425,3 +426,4 @@ system_uptime(FILE *f) {
 	fprintf(f, "%s uptime is", buf);
 	display_uptime(f, d);
 }
+
