@@ -23,12 +23,13 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ifst_linux.c,v 1.56 2004/03/19 08:59:42 vlm Exp $
+ * $Id: ifst_linux.c,v 1.62 2005/06/05 21:40:59 vlm Exp $
  */
 
 #include "ipcad.h"
 #include "disp.h"
 #include "sf_lite.h"
+#include "opt.h"
 
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -70,6 +71,10 @@ struct l_ifstat {
 static struct l_ifstat rt_pos;	/* Field positions for interface counters */
 static int rt_pos_initialized;	/* Field positions initialized */
 
+static FILE *pnd = NULL;	/* Pre-opened /proc/net/dev */
+static int uptime_fd = -1;
+static pthread_mutex_t uptime_mutex;
+
 int status(FILE *f, char *ifname);
 
 
@@ -205,9 +210,9 @@ if_stat(FILE *f, char *ifname) {
 
 static int
 fill_rt_pos(char *buf) {
-	slist *inio;	/* iface[0]|receive[1]|transmit[2] */
-	slist *inpsl;	/* bytes packets ... */
-	slist *outsl;	/* bytes packets ... */
+	svect *inio;	/* iface[0]|receive[1]|transmit[2] */
+	svect *inpsl;	/* bytes packets ... */
+	svect *outsl;	/* bytes packets ... */
 	int inindex;	/* shift in words from the start */
 	int outindex;	/* shift in words from the start */
 
@@ -287,7 +292,7 @@ fill_rt_pos(char *buf) {
 
 /* Get status from the string */
 struct l_ifstat *
-get_ifstat(slist *sl) {
+get_ifstat(svect *sl) {
 	struct l_ifstat *nif;
 
 #define	FIF(foo)	nif->foo = (((signed long)rt_pos.foo) > 0)?strtoul(sl->list[rt_pos.foo], NULL, 10):0L
@@ -337,26 +342,14 @@ display_ifstat(FILE *f, struct l_ifstat *ifs) {
 	return;
 };
 
-static FILE *pnd = NULL;
-pthread_mutex_t pnd_mutex;
-sig_atomic_t pnd_mutex_initialized = 0;
-
 int
 status(FILE *f, char *ifname) {
-	char buf[512];
-	slist *sl;
+	char buf[1024];
+	svect *sl;
 	struct l_ifstat *lfs;
 
-	if(!pnd_mutex_initialized) {
-		if(pthread_mutex_init(&pnd_mutex, NULL) == -1) {
-			fprintf(f, "     Verbose statistics unavailable: locking error\n");
-			return -1;
-		}
-		pnd_mutex_initialized = 1;
-	}
-
 	/* Lock all */
-	pthread_mutex_lock(&pnd_mutex);
+	pthread_mutex_lock(&pndev_lock);
 
 	if(!pnd) {
 		if(ifst_preopen() == -1) {
@@ -367,10 +360,13 @@ status(FILE *f, char *ifname) {
 		fseek(pnd, 0L, 0);
 	}
 
-	fgets(buf, sizeof(buf), pnd); /* Eat line */
-
+	/*
+	 * Eat two header lines.
+	 */
+	fgets(buf, sizeof(buf), pnd); /* Eat first header line */
 	if(fgets(buf, sizeof(buf), pnd) == NULL) {
-		fprintf(f, "     Verbose statistics unavailable: invalid format\n");
+		fprintf(f, "     Verbose statistics unavailable: "
+			"invalid format\n");
 		goto finish;
 	}
 
@@ -407,7 +403,7 @@ status(FILE *f, char *ifname) {
 			fprintf(f, "     Verbose statistics unavailable: resource shortage\n");
 			goto finish;
 		}
-		pthread_mutex_unlock(&pnd_mutex);
+		pthread_mutex_unlock(&pndev_lock);
 		return 0;
 	}
 
@@ -415,10 +411,55 @@ status(FILE *f, char *ifname) {
 
 finish:
 
-	pthread_mutex_unlock(&pnd_mutex);
+	pthread_mutex_unlock(&pndev_lock);
 	return -1;
 }
 
+#ifndef	IPCAD_IFLIST_USE_GETIFADDRS
+
+svect *
+get_interface_names() {
+	char buf[1024];
+	svect *sl;
+
+	if(!pnd) {
+		errno = ESRCH;
+		return NULL;
+	}
+
+	pthread_mutex_lock(&pndev_lock);
+	fseek(pnd, 0L, 0);
+
+	fgets(buf, sizeof(buf), pnd); /* Eat first header line */
+	if(fgets(buf, sizeof(buf), pnd) == NULL) {
+		pthread_mutex_unlock(&pndev_lock);
+		return NULL;
+	}
+
+	sl = sinit();
+	while(fgets(buf, sizeof(buf), pnd)) {
+		char *ifname, *p;
+		for(ifname = buf; *ifname && *ifname == ' '; ifname++);
+		for(p = ifname; *p; p++) {
+			switch(*p) {
+			default: continue;
+			case ':': case ' ': case '\t': case '|':
+				if(sadd2(sl, ifname, p - ifname) == -1) {
+					sfree(sl);
+					sl = NULL;
+					break;
+				}
+			}
+			break;
+		}
+	}
+
+	pthread_mutex_unlock(&pndev_lock);
+	return sl;
+}
+
+#endif	/* IPCAD_IFLIST_USE_GETIFADDRS */
+
 
 #ifndef	_PATH_PROCNET_DEV
 #define	_PATH_PROCNET_DEV	"/proc/net/dev"
@@ -428,21 +469,14 @@ finish:
 #define	_PATH_PROC_UPTIME	"/proc/uptime"
 #endif
 
-static int uptime_fd = -1;
-static pthread_mutex_t uptime_mutex;
-
 int
 ifst_preopen() {
-	pnd = fopen(_PATH_PROCNET_DEV, "r");
-	if(pnd == NULL)
-		return -1;
-	setbuf(pnd, NULL);
-
-	if(pthread_mutex_init(&pnd_mutex, NULL) == -1)
-		return -1;
-
 	uptime_fd = open(_PATH_PROC_UPTIME, O_RDONLY);
 
+	pnd = fopen(_PATH_PROCNET_DEV, "r");
+	if(pnd)	setbuf(pnd, NULL);
+	else	return -1;
+
 	return 0;
 }
 
