@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ifst_unk.c,v 1.5 2004/03/09 22:08:37 vlm Exp $
+ * $Id: ifst_unk.c,v 1.8 2004/06/25 15:29:06 vlm Exp $
  */
 
 #include "ipcad.h"
@@ -31,6 +31,8 @@
 int
 if_stat(FILE *f, char *iface) {
 
+	(void)iface;
+
 	fprintf(f, "Unknown system to gather interface statistics.\n");
 
 	return 0;
@@ -44,5 +46,6 @@ ifst_preopen() {
 
 void
 system_uptime(FILE *f) {
-	(f);
+	(void)f;
 }
+
