@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2001, 2002 Lev Walkin <vlm@lionet.info>.
+ * Copyright (c) 2001, 2002, 2006 Lev Walkin <vlm@lionet.info>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: import.c,v 1.15 2004/03/11 09:36:00 vlm Exp $
+ * $Id: import.c,v 1.23 2006/11/21 14:56:36 vlm Exp $
  */
 
 #include "ipcad.h"
@@ -35,10 +35,10 @@
 int
 import_table(char *dump_file, FILE *msgstream, int clear) {
 	const int check_owner = 1;
-	size_t entries = 0;
+	long entries = 0;
 	struct in_addr src, dst;
 	time_t a_d_a = 0; /* Accounting data age */
-	char buf[7][256];
+	char buf[9][256];
 	struct stat sb;
 	flow_t flow;
 	FILE *f;
@@ -79,7 +79,7 @@ import_table(char *dump_file, FILE *msgstream, int clear) {
 
 	if(check_owner) {
 		uid_t should_be = conf->set_uid;
-		if((long)should_be <= 0)
+		if((int)should_be <= 0)
 			should_be = getuid();
 		if(sb.st_uid != should_be) {
 			fprintf(msgstream,
@@ -94,7 +94,8 @@ import_table(char *dump_file, FILE *msgstream, int clear) {
 	}
 
 	if((sb.st_mode & 0077)) {
-		fprintf(msgstream, "Insecure dump file permissions.\n");
+		fprintf(msgstream, "Insecure dump file permissions. "
+			"Try `chmod 600 %s`\n", dump_file);
 		fclose(f);
 		return -1;
 	}
@@ -140,10 +141,13 @@ import_table(char *dump_file, FILE *msgstream, int clear) {
 		if(buf[0][0] != ' ')
 			continue;
 
-		tokens = sscanf(buf[0], " %s %s %s %s %s %s",
+		tokens = sscanf(buf[0], " %s %s %s %s %s %s %s %s",
 				buf[1], buf[2], buf[3], buf[4],
-				buf[5], buf[6]);
-		if(tokens != 4 && tokens != 6)
+				buf[5], buf[6],	/* Ports */
+				buf[7],		/* Protocol */
+				buf[8]		/* Interface name */
+			);
+		if(tokens != 4 && tokens != 8)
 			continue;
 		/*
 		 * Source and destination IP addresses.
@@ -156,13 +160,20 @@ import_table(char *dump_file, FILE *msgstream, int clear) {
 		errno = 0;
 		flow.src = src;
 		flow.dst = dst;
-		if(tokens == 6) {
+		if(tokens == 8) {
 			flow.src_port = atoi(buf[5]);
 			flow.dst_port = atoi(buf[6]);
+			flow.ip_p = atoi(buf[7]);
+			strncpy(flow.ifInName, buf[8], sizeof(flow.ifInName));
+			flow.ifInName[sizeof(flow.ifInName) - 1] = '\0';
 		} else {
 			flow.src_port = -1;
 			flow.dst_port = -1;
+			flow.ip_p = 0;
+			flow.ifInName[0] = '\0';
 		}
+		flow.ifInIndex = -1;
+		flow.ifOutIndex = -1;
 		flow.packets = strtoul(buf[3], NULL, 10);
 		flow.bytes = strtoull(buf[4], NULL, 10);
 		if(errno)	/* strtouX error */
@@ -185,16 +196,49 @@ import_table(char *dump_file, FILE *msgstream, int clear) {
 		return 0;
 	}
 
-	if(clear)
-		fprintf(msgstream,
-			"%d elements got from %s.\n",
-			entries, dump_file);
-	else
-		fprintf(msgstream,
-			"%d elements added from %s.\n",
-			entries, dump_file);
+	fprintf(msgstream, "%s %ld elements from %s.\n",
+		clear ? "Got" : "Added", entries, dump_file);
+
+	if(clear && entries) {
+		/* Analyse hash for collisions */
+		double sumsq = 0.0;
+		double sum = 0.0;
+		int longest_chain = 0;
+		int longest_chain_no = 0;
+		int numbuckets;
+		int bucket;		/* Bucket number */
+
+		lock_storage(&active_storage);
+		for(bucket = 0; bucket < active_storage.numbuckets; bucket++) {
+			int chainLength = 0;
+			flow_el_t *cur;
+
+			/* Allow others to run... */
+			unlock_storage(&active_storage);
+			lock_storage(&active_storage);
+
+			for(cur = active_storage.buckets[bucket];
+					cur; cur = cur->bucket_next)
+				chainLength++;
+			if(longest_chain < chainLength) {
+				longest_chain = chainLength;
+				longest_chain_no = bucket;
+			}
+
+			sumsq += ((double)chainLength) * chainLength;
+			sum += chainLength;
+		}
+		numbuckets = active_storage.numbuckets;
+		unlock_storage(&active_storage);
+
+		fprintf(stderr, "Storage: chained %d in %d bucket out of %d, mean %.1f dev^2 %.1f\n",
+			longest_chain, longest_chain_no, numbuckets,
+			sum / numbuckets,
+			sumsq / numbuckets
+				- (sum * sum / numbuckets / numbuckets)
+		);
+	}
 
 	return 0;
 }
 
-
