@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: main.c,v 1.34 2004/03/19 08:59:42 vlm Exp $
+ * $Id: main.c,v 1.44 2004/09/17 05:37:58 vlm Exp $
  */
 
 #include "ipcad.h"
@@ -42,23 +42,18 @@ void terminate_threads();
 
 void
 sigalarm(int z) {
-	//fprintf(stderr, "Thread %ld alarmed.\n", (long)pthread_self());
 	signal(z, sigalarm);
 }
 
 void
 set_display_now(int z) {
-
 	display_now = 1;
-
 	signal(z, set_display_now);
 }
 
 void
 sigquit(int z) {
-
 	signoff_now = 1;
-	
 	signal(z, sigquit);
 }
 
@@ -75,6 +70,7 @@ main(int ac, char **av) {
 	int pidfile_fd = -1;
 	int devnull_fd = -1;
 	int c;
+	unsigned i;
 
 	gettimeofday(&tv, NULL);
 	self_started = tv.tv_sec + (double)tv.tv_usec / 1000000;
@@ -103,7 +99,7 @@ main(int ac, char **av) {
 			break;
 		case 'v':
 			fprintf(stderr,
-				IPCAD_VERSION_STRING "\n"
+				IPCAD_VERSION_STRING
 				IPCAD_COPYRIGHT "\n");
 			exit(EX_USAGE);
 		default:
@@ -125,10 +121,12 @@ main(int ac, char **av) {
 	conf->netflow_timeout_active = 30 * 60;	/* Seconds */
 	conf->netflow_timeout_inactive = 15;	/* Seconds */
 	conf->netflow_packet_interval = 1;	/* packets of packets */
+	for(i = 0; i < sizeof(agr_portmap)/sizeof(agr_portmap[0]); i++)
+		agr_portmap[i] = i;	/* Default is 1:1 mapping. */
 
-	if(cfgread(config_file))
-		exit(EX_NOINPUT);
-
+	/*
+	 * Open /dev/null for daemonizing.
+	 */
 	devnull_fd = open(_PATH_DEVNULL, O_RDWR, 0);
 	if(devnull_fd == -1) {
 		fprintf(stderr, "Can't open " _PATH_DEVNULL ": %s\n",
@@ -136,6 +134,12 @@ main(int ac, char **av) {
 		exit(EX_OSERR);
 	}
 
+	/*
+	 * Read specified or default configuration file.
+	 */
+	if(cfgread(config_file))
+		exit(EX_NOINPUT);
+
 	/******************************/
 	/* Process configuration data */
 	/******************************/
@@ -158,6 +162,9 @@ main(int ac, char **av) {
 	/*
 	 * Simple deeds.
 	 */
+	/* Pre-open certain files before doing chroot(). */
+	if(ifst_preopen())
+		exit(EX_OSERR);
 
 	/* Security */
 	if(draw_restricted_envir(DRAW_CHROOT))
@@ -169,7 +176,7 @@ main(int ac, char **av) {
 		pidfile_fd = make_pid_file(conf->pidfile);
 		if(pidfile_fd == -1) {
 			fprintf(stderr,
-				"Can't intialize pid file %s%s%s: %s\n",
+				"Can't initialize pid file %s%s%s: %s\n",
 				conf->chroot_to?conf->chroot_to:"",
 				conf->chroot_to?"/":"",
 				conf->pidfile, strerror(errno));
@@ -194,6 +201,8 @@ main(int ac, char **av) {
 
 	/* Daemon mode should be entered BEFORE threads created. */
 	if(daemon_mode) {
+		fflush(NULL);
+
 		switch(fork()) {
 		case -1:
 			perror("ipcad");
@@ -302,8 +311,11 @@ main(int ac, char **av) {
 
 	/* Leave the pid file gracefully */
 	if(pidfile_fd != -1) {
-		(void)write_pid_file(pidfile_fd, 0, "finished\n");
-		close(pidfile_fd);
+		int fd = pidfile_fd;
+		pidfile_fd = -1;
+		/* Empty the .pid file */
+		(void)write_pid_file(fd, 0, "");
+		close(fd);
 	}
 
 	fprintf(stderr, "Quit.\n");
@@ -311,14 +323,24 @@ main(int ac, char **av) {
 	return 0;
 }
 
+/*
+ * Block signals that must be handled by the main thread only.
+ */
+int
+block_certain_signals(sigset_t *old_set) {
+	sigset_t set;
+	sigemptyset(&set);
+	sigaddset(&set, SIGINT);
+	sigaddset(&set, SIGHUP);
+	sigaddset(&set, SIGQUIT);
+	sigaddset(&set, SIGTERM);
+	return sigprocmask(SIG_BLOCK, &set, old_set);
+}
+
 int
 draw_restricted_envir(enum phase phase) {
 
 	if(phase == DRAW_CHROOT) {
-		/*
-		 * Pre-open files before doing chroot().
-		 */
-		ifst_preopen();
 
 		if(conf->chroot_to == NULL)
 			/* We were not told to do chroot() */
@@ -365,38 +387,51 @@ terminate_threads() {
 
 	end_servers();
 
-	printf("Waiting for interface processing threads to terminate...\n");
+	printf("Signalling interface threads");
+	for(ps = conf->packet_sources_head; ps; ps = ps->next) {
+		if(!ps->thid)
+			continue;
+
+		printf("."); fflush(stdout);
+
+#ifdef	HAVE_PTHREAD_CANCEL
+		/*
+		 * When libpcap is being used, the dispatcher function
+		 * does not return when -1/EINTR is received from the
+		 * capture device socket. It just retries to read,
+		 * blocking the whole process.
+		 * This pthread_cancel() ensures that the thread will
+		 * be killed doing such a nasty loop.
+		 */
+		pthread_cancel(ps->thid);
+#endif
+
+		/* Notify the process */
+		pthread_kill(ps->thid, SIGALRM);
+	}
+
+	printf("\nWaiting for interface processing threads to terminate...\n");
 
 	for(ps = conf->packet_sources_head; ps; ps = ps->next) {
 		if(!ps->thid)
 			continue;
 
-		if(pthread_cancel(ps->thid)) {
-			printf("%s processing thread is already gone.\n",
-				ps->ifName);
-			ps->thid = 0;
-			continue;
-		}
-
-		/* Notify the process */
-		pthread_kill(ps->thid, SIGALRM);
-
 		if(pthread_join(ps->thid, NULL)) {
 			if(errno == EINVAL)
 				printf("Thread processing %s "
 					"is not a joinable thread.\n",
-					ps->ifName);
+					IFNameBySource(ps));
 			if(errno == ESRCH)
 				printf("No thread running "
 					"for processing %s\n",
-					ps->ifName);
+					IFNameBySource(ps));
 			if(errno == EDEADLK)	/* Impossible state */
 				printf("Deadlock avoided "
 					"for thread processing %s\n",
-					ps->ifName);
+					IFNameBySource(ps));
 		} else {
 			printf("Thread processing %s terminated.\n",
-				ps->ifName);
+				IFNameBySource(ps));
 		}
 	}
 }
