@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: opt.c,v 1.12 2004/03/19 08:12:31 vlm Exp $
+ * $Id: opt.c,v 1.14 2004/05/10 08:42:35 vlm Exp $
  */
 
 #include "headers.h"
@@ -36,6 +36,8 @@ volatile sig_atomic_t signoff_now = 0;
 
 volatile int max_clients = 10;
 pthread_mutex_t max_clients_lock;
+pthread_mutex_t packet_sources_list_lock;
+pthread_mutex_t pndev_lock;
 
 pthread_attr_t	thread_attr_detach;
 
@@ -45,6 +47,12 @@ init_pthread_options() {
 	if(pthread_mutex_init(&max_clients_lock, NULL) == -1)
 		return -1;
 
+	if(pthread_mutex_init(&packet_sources_list_lock, NULL) == -1)
+		return -1;
+
+	if(pthread_mutex_init(&pndev_lock, NULL) == -1)
+		return -1;
+
 	if(pthread_mutex_init(&fd_pool_mutex, NULL) == -1)
 		return -1;
 
