@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: pps.c,v 1.21 2004/03/06 05:30:40 vlm Exp $
+ * $Id: pps.c,v 1.27 2004/09/17 05:49:55 vlm Exp $
  */
 
 
@@ -114,37 +114,36 @@ adjust_stats(packet_source_t *pss) {
 int
 process_packet_sources(packet_source_t *pss) {
 	packet_source_t *ps;
-	sigset_t set, oset;
+	sigset_t old_set;
 
 	/*
-	 * Block all signals.
+	 * Do not allow other threads receive signals for the main thread.
 	 * The signal mask is inherited from the creating thread.
 	 */
-	sigfillset(&set);
-	sigprocmask(SIG_BLOCK, &set, &oset);
+        block_certain_signals(&old_set);
 
 	/* Run threads */
 	for(ps = pss; ps; ps = ps->next) {
-		if( pthread_create(&ps->thid, NULL, ps->loop_ptr, ps) ) {
+		if( pthread_create(&ps->thid, NULL, ps->process_ptr, ps) ) {
 			fprintf(stderr,
 				"Can't start thread for %s!\n",
-				ps->ifName);
+				IFNameBySource(ps));
 			signoff_now = 1;
-			sigprocmask(SIG_SETMASK, &oset, NULL);
+			sigprocmask(SIG_SETMASK, &old_set, NULL);
 			return -1;
 		} else {
-			printf("Thread %ld processing %s started.\n",
-				(long)ps->thid, ps->ifName);
+			printf("Thread %lu processing %s started.\n",
+				(long)ps->thid, IFNameBySource(ps));
 		}
 	}
 
-	sigprocmask(SIG_SETMASK, &oset, NULL);
+	sigprocmask(SIG_SETMASK, &old_set, NULL);
 
 	/* Signal-processing loop */
 
 #define	SLEEP_TIME	2	/* Seconds */
 
-	while(1) {
+	for(;;) {
 		sleep(SLEEP_TIME);
 
 		if(signoff_now)
