@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: rsh.c,v 1.17 2004/03/23 17:43:42 vlm Exp $
+ * $Id: rsh.c,v 1.22 2005/03/20 14:17:57 vlm Exp $
  */
 
 #include "ipcad.h"
@@ -37,7 +37,7 @@
  */
 extern int process_rsh_request(int sock);
 
-int rsh_rw_timeout;	/* RSH read-write timeout */
+int rsh_rw_timeout = 30000;	/* RSH read-write timeout */
 
 static void *prr_handler();
 static int fork_rsh_request(int client);
@@ -48,11 +48,10 @@ rsh_server(void *srvp) {
 	struct sockaddr_in sin;
 	struct sockaddr_in srem;
 	server *srv = (server *)srvp;
-	size_t	addrlen;
+	socklen_t addrlen;
 	int lcmd = 0;	/* Listening socket at "shell" (514) */
 	int client;
 	socklen_t on = 1;
-	sigset_t set, oset;
 
 	if((lcmd = socket(PF_INET, SOCK_STREAM, IPPROTO_TCP)) == -1) {
 		fprintf(stderr, "Can't create socket for %s.\n",
@@ -81,23 +80,14 @@ rsh_server(void *srvp) {
 	/* Flag for parent thread */
 	srv->started_ok = 1;
 
-	sigemptyset(&set);
-	sigaddset(&set, SIGALRM);
-
-	while(1) {
+	for(;;) {
 
 		if(signoff_now)
 			break;
 
-		/* Unblock SIGALRM */
-		sigprocmask(SIG_UNBLOCK, &set, &oset);
-
 		addrlen = sizeof(srem);
 		client = accept(lcmd, (struct sockaddr *)&srem, &addrlen);
 
-		/* Block SIGARLM */
-		sigprocmask(SIG_SETMASK, &oset, NULL);
-
 		if(signoff_now)
 			break;
 
@@ -213,6 +203,7 @@ set_rsh_client_socket_options(int client) {
 
 #ifdef	IPPROTO_IP
 
+#if	0	/* Does not work on FreeBSD 5.3 with pf enabled */
 #ifndef	__OpenBSD__
 #ifdef	TCP_NODELAY
 	/* Disable Nagle algorithm for efficiency */
@@ -220,6 +211,7 @@ set_rsh_client_socket_options(int client) {
 	setsockopt(client, IPPROTO_IP, TCP_NODELAY, &l, sizeof(l));
 #endif	/* TCP_NODELAY */
 #endif	/* __OpenBSD__ */
+#endif
 
 #ifdef	IP_TTL
 	/* Set TTL reasonably low to avoid remote attacks */
