@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: rw.c,v 1.5 2004/03/06 05:31:12 vlm Exp $
+ * $Id: rw.c,v 1.6 2004/06/25 13:41:33 vlm Exp $
  */
 
 #include "ipcad.h"
@@ -39,7 +39,7 @@ read_timeout(int sockfd, void *buf, size_t nbytes, int to_ms) {
 	pfd.fd = sockfd;
 	pfd.events = POLLIN;
 
-	while(1) {
+	for(;;) {
 
 		rc = poll(&pfd, 1, to_ms);
 
