@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: servers.c,v 1.7 2004/03/06 05:30:08 vlm Exp $
+ * $Id: servers.c,v 1.10 2006/04/07 18:58:02 vlm Exp $
  */
 
 #include "ipcad.h"
@@ -64,18 +64,21 @@ add_server(void *(*func)(void *), char *name, struct in_addr *ip, int hport) {
 
 int
 start_servers() {
-	sigset_t set, oset;
+	sigset_t old_set;
 	server *srv;
 	int rc;
 
 	if(!servers_head) {
-		printf("No servers defined. How you will gather data? ;)\n");
+		if(daemon_mode)
+		printf("No servers defined. How will you gather data? ;)\n");
 		return 0;
 	}
 
-	/* Block all signals */
-	sigfillset(&set);
-	sigprocmask(SIG_BLOCK, &set, &oset);
+	/*
+	 * Do not allow other threads receive signals for the main thread.
+	 * The signal mask is inherited from the creating thread.
+	 */
+	block_certain_signals(&old_set);
 
 	/* Iterate through defined servers */
 	for(srv = servers_head; srv; srv=srv->next) {
@@ -104,21 +107,19 @@ start_servers() {
 		if(rc == -1) {
 			srv->thid = 0;
 
-			/* Unblock signals */
-			sigprocmask(SIG_SETMASK, &oset, NULL);
-
 			/* Terminate previously started servers */
 			end_servers();
+			sigprocmask(SIG_SETMASK, &old_set, NULL);
 			return -1;
 		}
 
-		printf("%s thread started.\n", srv->name);
+		printf("%s thread %lu started.\n",
+			srv->name, (long)srv->thid);
 
 	}
 
-	/* Unblock signals */
-	sigprocmask(SIG_SETMASK, &oset, NULL);
-	
+	sigprocmask(SIG_SETMASK, &old_set, NULL);
+
 	return 0;
 }
 
@@ -133,20 +134,15 @@ end_servers_r(server *srv) {
 	/* If alive */
 	if(srv->thid && srv->started_ok) {
 
-		/* Trying to cancel */
-		if(pthread_cancel(srv->thid)) {
-			printf("%s thread is already gone.\n", srv->name);
-		} else {
-			/* Kick it */
-			pthread_kill(srv->thid, SIGALRM);
+		/* Kick it */
+		pthread_kill(srv->thid, SIGALRM);
 
-			printf("Waiting for %s thread to terminate... ",
-				srv->name);
-			fflush(stdout);
+		printf("Waiting for %s thread to terminate... ",
+			srv->name);
+		fflush(stdout);
 
-			pthread_join(srv->thid, NULL);
-			printf("DONE.\n");
-		}
+		pthread_join(srv->thid, NULL);
+		printf("DONE.\n");
 
 	}	/* if(thid) */
 
