@@ -1,10 +1,9 @@
 /*
- * This code was taken from the libstrfunc project,
- * http://www.spelio.net.ru/soft
+ * This code was taken from the libstrfunc project, http://lionet.info
  * All rights reserved.
  */
 /*-
- * Copyright (c) 1999, 2000, 2001 Lev Walkin <vlm@spelio.net.ru>.
+ * Copyright (c) 1999, 2000, 2001 Lev Walkin <vlm@lionet.info>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -28,7 +27,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: sf_lite.c,v 1.3 2004/03/19 08:12:31 vlm Exp $
+ * $Id: sf_lite.c,v 1.5 2005/05/25 21:07:00 vlm Exp $
  */
 
 #include <stdio.h>
@@ -64,25 +63,27 @@
 #define	sf_calloc	calloc
 #define	sf_realloc	realloc
 
-int eq(const char *a, const char *b) { return !strcmp(a, b); }
-
-/* create or initialize empty slist structure */
-slist *
+/*
+ * Create or initialize empty string list.
+ */
+svect *
 sinit() {
-	slist *sl;
+	svect *sl;
 
-	sl=(slist *)sf_calloc(1, sizeof(slist));
+	sl=(svect *)sf_calloc(1, sizeof(svect));
 	if(!sl)
 		return NULL;
 
 	sl->listlen = 4;
 
+	/* Place for data chunks */
 	sl->list = (char **)sf_malloc(sizeof(char *) * sl->listlen);
 	if(!sl->list) {
 		free(sl);
 		return NULL;
 	}
 
+	/* Place for data lengths */
 	sl->lens = (size_t *)sf_malloc(sizeof(size_t) * sl->listlen);
 	if(!sl->lens) {
 		free(sl->list);
@@ -90,15 +91,15 @@ sinit() {
 		return NULL;
 	}
 
-	*(sl->list) = NULL;
-	*(sl->lens) = 0;
+	sl->list[0] = NULL;
+	sl->lens[0] = 0;
 
 	return sl;
 };
 
-/* frees any strings inside the slist object */
+/* frees any strings inside the svect object */
 void
-sclear(slist *sl) {
+sclear(svect *sl) {
 
 	if(sl == NULL)
 		return;
@@ -119,19 +120,20 @@ sclear(slist *sl) {
 
 	sl->lens = 0;
 	sl->count = 0;
-	sl->maxlen = 0;
 	sl->listlen = 0;
 }
 
 void
-sfree(slist *sl) {
+sfree(svect *sl) {
 	if(!sl)
 		return;
 
 	if(sl->list) {
 		if(sl->count > 0)
-			while(sl->count--)
-				free(sl->list[sl->count]);
+			while(sl->count--) {
+				void *p = sl->list[sl->count];
+				if(p) free(p);
+			}
 		free(sl->list);
 	};
 
@@ -143,7 +145,7 @@ sfree(slist *sl) {
 
 /* Basic adding function */
 int
-_sf_add_internal(slist *s, void *msg, size_t len) {
+_sf_add_internal(svect *s, void *msg, size_t len) {
 
 	if(s->count + 1 >= s->listlen) {
 		void *z;
@@ -169,9 +171,6 @@ _sf_add_internal(slist *s, void *msg, size_t len) {
 	s->list[s->count] = msg;
 	s->lens[s->count] = len;
 
-	if(len > s->maxlen)
-		s->maxlen = len;
-
 	s->count++;
 	s->list[s->count] = NULL;
 	s->lens[s->count] = 0;
@@ -180,9 +179,9 @@ _sf_add_internal(slist *s, void *msg, size_t len) {
 }
 
 
-/* Add a string to the end of the slist structure */
+/* Add a string to the end of the svect structure */
 int
-sadd2(slist *s, char *msg, size_t len) {
+sadd2(svect *s, char *msg, size_t len) {
 	char *tmp;
 
 	if(!s || !msg)
@@ -203,7 +202,7 @@ sadd2(slist *s, char *msg, size_t len) {
 };
 
 int
-sadd(slist *s, char *msg) {
+sadd(svect *s, char *msg) {
 	if(!s || !msg)
 		return -1;
 	return sadd2(s, msg, strlen(msg));
@@ -212,7 +211,7 @@ sadd(slist *s, char *msg) {
 
 /* delete i'th string from the list */
 int
-sdel(slist *s, size_t n) {
+sdel(svect *s, size_t n) {
 	if(!s)
 		return -1;
 
@@ -230,19 +229,16 @@ sdel(slist *s, size_t n) {
 }
 
 ssize_t
-sfind(slist *sl, const char *what) {
+sfind(svect *sl, const char *what) {
 	size_t n;
 	size_t wlen;
-	short sw;
+	char cw;
 
 	if(!sl || !sl->count || !what)
 		return -1;
 
 	wlen=strlen(what);
-	if(wlen)
-		sw = *(short *)what;
-	else
-		sw = 0;	/* will never be used */
+	cw = *what;
 
 	for(n=0; n < sl->count; n++) {
 
@@ -251,7 +247,7 @@ sfind(slist *sl, const char *what) {
 
 		if(wlen) {
 			if(
-				(*(short *)sl->list[n] == sw)
+				(sl->list[n][0] == cw)
 				&& !strcmp(sl->list[n], what)
 			) return n;
 		} else {
@@ -267,32 +263,36 @@ sfind(slist *sl, const char *what) {
 /* SPLIT STRING */
 /****************/
 
-/* split string and add its contents to the slist structure */
+/* split string and add its contents to the svect structure */
 /* Split: full version */
 int
-splitf(slist *s, char *msg, char *dlm, int strict) {
+splitf(svect *s, char *msg, char *dlm, int flags) {
 	char *p = msg;
 	char *w = NULL;
 	int tokens = 0;
 	int dlen;
 	char cp, cd;
 
-	if(!s || !p)
-		return 0;
+	if(!s || !p) {
+		errno = EINVAL;
+		return -1;
+	}
 
 	if(!dlm) {
-		if(strict & 4)
-			strict &= ~4;
+		if(flags & 4)
+			flags &= ~4;
 
-		if(strict)
+		if(flags)
+			/* Default to parse /etc/password-like strings */
 			dlm = ":";
 		else
+			/* Default to split on common whitespaces */
 			dlm = " \t\n\r";
 	}
 	cd = *dlm;
 	dlen = strlen(dlm);
 
-	if(strict & 2) {
+	if(flags & 2) {
 
 		for(; (cp = *p); p++) {
 			if((cd == cp) && (strncmp(p, dlm, dlen) == 0)) {
@@ -304,7 +304,7 @@ splitf(slist *s, char *msg, char *dlm, int strict) {
 					}
 					w = NULL;
 					tokens++;
-				} else if(strict & 1) {
+				} else if(flags & 1) {
 					if(sadd2(s, "", 0) == -1) {
 						while(tokens--)	/* cleanup */
 							sdel(s, s->count - 1);
@@ -331,7 +331,7 @@ splitf(slist *s, char *msg, char *dlm, int strict) {
 					};
 					w = NULL;
 					tokens++;
-				} else if(strict & 1) {
+				} else if(flags & 1) {
 					if(sadd2(s, "", 0) == -1) {
 						while(tokens--)
 							sdel(s, s->count -1);
@@ -355,15 +355,15 @@ splitf(slist *s, char *msg, char *dlm, int strict) {
 	return tokens;
 }
 
-slist *
-split(char *msg, char *delim, int strict) {
-	slist *sl;
+svect *
+split(char *msg, char *delim, int flags) {
+	svect *sl;
 
 	sl = sinit();
 	if(!sl)
 		return NULL;
 
-	if(splitf(sl, msg, delim, strict) == -1) {
+	if(splitf(sl, msg, delim, flags) == -1) {
 		sfree(sl);
 		return NULL;
 	}
@@ -371,74 +371,12 @@ split(char *msg, char *delim, int strict) {
 	return sl;
 }
 
-
-int
-split_network(const char *ipmp, unsigned int *ip, unsigned int *mask) {
-	unsigned long t;
-	char *msk = NULL;
-	char *ipm;
-
-	if(!ip || !mask)
-		return -1;
-
-	if(!ipmp) {
-		*ip = 0;
-		*mask = 0;
-		return -1;
-	};
-
-	t = strlen(ipmp) + 1;
-	if(t > 32)	/* Too long address/mask */
-		return -1;
-
-	msk = (char *)alloca(t);
-	memcpy(msk, ipmp, t);
-	ipm = msk;
-
-	if((msk=strchr(ipm, '/')) || (msk = strchr(ipm, ' ')))
-		*msk++ = 0;
-
-	if(!sf_iaton(ipm, ip)) {
-		*ip = *mask = 0;
-		return -1;
-	};
-
-	if(!msk) {
-		*mask = 0xffffffff;
-		return 0;
-	};
-
-	t = strchr(msk, '.')?1:0;
-	if(t && !sf_iaton(msk, mask)) {
-		*ip = *mask = 0;
-		return -1;
-	};
-	if(!t) {
-		errno=0;
-		if(msk[0] == '0' && msk[1] == 'x') {
-			t = strtoul(msk, NULL, 16);
-			*mask = htonl(t);
-		} else {
-			t = strtoul(msk, NULL, 10);
-			if((t > 32) || errno) return -1;
-			if(!t) *mask = 0;
-			else *mask = htonl(0xffffffff << (32 - t));
-		}
-	};
-
-	*ip = *ip & *mask;
-
-	return 0;
-}
-
-
-
 /*
  * This file was shamelessly stollen from FreeBSD's inet_addr.c to obtain
  * feature portability with other systems.
- * Cosmetic changes, Copyright (c) 2001, Lev Walkin <vlm@spelio.net.ru>.
+ * Cosmetic changes, Copyright (c) 2001, Lev Walkin <vlm@lionet.info>.
  *
- * $Id: sf_lite.c,v 1.3 2004/03/19 08:12:31 vlm Exp $
+ * $Id: sf_lite.c,v 1.5 2005/05/25 21:07:00 vlm Exp $
  */
 
 /*
