@@ -1,10 +1,9 @@
 /*
- * This code was taken from the libstrfunc project,
- * http://www.spelio.net.ru/soft
+ * This code was taken from the libstrfunc project, http://lionet.info
  * All rights reserved.
  */
 /*-
- * Copyright (c) 1999, 2000, 2001 Lev Walkin <vlm@spelio.net.ru>.
+ * Copyright (c) 1999, 2000, 2001 Lev Walkin <vlm@lionet.info>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -28,44 +27,43 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: sf_lite.h,v 1.2 2004/03/06 05:25:58 vlm Exp $
+ * $Id: sf_lite.h,v 1.3 2005/05/25 21:07:00 vlm Exp $
  */
 
 #ifndef __SF_LITE_H__
 #define __SF_LITE_H__
 
-	/***********************/
-	/*** 1. String lists ***/
-	/***********************/
+	  /*************************/
+	 /*** 1. String vectors ***/
+	/*************************/
 
+/*
+ * A vector of known size lengths.
+ */
 typedef struct {
-    char **list;
-    size_t	count;
-    size_t	listlen;
-	size_t	maxlen;
+	char   **list;
 	size_t	*lens;
-} slist;
+	size_t	count;		/* Count of active elements */
+	size_t	listlen;	/* Allocated size */
+} svect;
 
-slist	*sinit();			/* Create empty structure */
-void	sclear(slist *);	/* Clear elements of filled structure */
-void	sfree(slist *);	/* Destroy entire object completely */
+svect	*sinit(void);		/* Create empty string vector */
+void	sclear(svect *);	/* Clear elements of filled structure */
+void	sfree(svect *);		/* Destroy the entire object vector */
 
 /* Add element to the end of list */
-int	sadd(slist *, char *toadd);	/* with strdup(toadd) */
-int	sadd2(slist *, char *toadd, size_t len); /* With length. */
+int	sadd(svect *, char *toadd);	/* with strdup(toadd) */
+int	sadd2(svect *, char *toadd, size_t len); /* With length. */
 
-int	sdel(slist *, size_t num);	/* Delete specified element */
-ssize_t sins(slist *, char *, size_t num); /* Insert element before num */
+int	sdel(svect *, size_t num);	/* Delete specified element */
+ssize_t sins(svect *, char *, size_t num); /* Insert element before num */
 
-/* Split functions, my aknowledgements to Larry Wall! */
-slist *split(char *what, char *delim, int strict); /* creates new (slist *) */
-int splitf(slist *sl, char *what, char *delim, int strict);
-int split_network(const char *, unsigned int *ip, unsigned int *mask);
+/* String splitting functions */
+svect *split(char *what, char *delim, int flags); /* creates new (svect *) */
+int splitf(svect *sl, char *what, char *delim, int strict);
 int sf_iaton(const char *cp, unsigned int *pin); /* aka inet_aton */
 
 /* Find element */
-ssize_t sfind(slist *, const char *);	/* Case-sensitive */
-
-int eq(const char *a, const char *b);	/* Equality test */
+ssize_t sfind(svect *, const char *);	/* Case-sensitive */
 
 #endif	/* __SF_LITE_H__ */
